Welcome to ezhost
========================

.. image:: https://readthedocs.org/projects/ezhost/badge/?version=latest
    :target: http://ezhost.readthedocs.io/en/latest/#

.. image:: https://travis-ci.org/zhexiao/ezhost.svg?branch=master
    :target: https://travis-ci.org/zhexiao/ezhost/builds
    
.. image:: https://coveralls.io/repos/github/zhexiao/ezhost/badge.svg?branch=master
    :target: https://coveralls.io/github/zhexiao/ezhost?branch=master
    
.. image:: https://www.versioneye.com/user/projects/57475872ce8d0e0047372ed6/badge.svg
    :target: https://www.versioneye.com/user/projects/57475872ce8d0e0047372ed6
    

Purpose
============

This tool is aim to make user easy to install server, operate remote server from local pc.


Requirements
============

* Python 3.3+
* python3-pip
* python3.4-venv


Documentation for ezhost
=============================

You will find complete documentation for setting up ezhost at `the Docs site`_.

.. _the Docs site: http://ezhost.readthedocs.io/en/latest/